@@ -259,9 +259,9 @@ Clones this instance and returns it.
 
 Each element is cloned by L<Cloneable#clone|SPVM::Cloneable/"clone"> method if it is defined, otherwise undef is assigned.
 
-=head2 push_array
+=head2 push_
 
-C<method push_array : void ($elements : byte[]);>
+C<method push_ : void ($elements : object[]);>
 
 Adds the elements $elements after the end of this list.
 
@@ -273,9 +273,9 @@ The elements $elements must be defined.
 
 Exceptions thrown by L</"push"> method could be thrown.
 
-=head2 unshift_array
+=head2 unshift_
 
-C<method unshift_array : void ($elements : byte[]);>
+C<method unshift_ : void ($elements : object[]);>
 
 Inserts the elemnets $elements at the beginning of the list.
 
